@@ -16,13 +16,13 @@ use Tie::IxHash;
 use Business::CreditCard qw(cardtype);
 use Data::Dumper;
 use IO::String;
-use Carp qw(croak);
+use Carp qw(croak carp);
 use Log::Scrubber qw(disable $SCRUBBER scrubber :Carp scrubber_add_scrubber);
 
 @ISA     = qw(Business::OnlinePayment::HTTPS);
 $me      = 'Business::OnlinePayment::Litle';
 $DEBUG   = 0;
-our $VERSION = '0.958'; # VERSION
+our $VERSION = '0.959'; # VERSION
 
 # PODNAME: Business::OnlinePayment::Litle
 
@@ -122,7 +122,7 @@ sub set_defaults {
     if( defined $_defaults{'Scrubber'} ) {
         my $code = $_defaults{'Scrubber'};
         if( ref($code) ne 'CODE' ) {
-            warn('default_Scrubber is not a code ref');
+            carp('default_Scrubber is not a code ref');
         }
         else {
             $self->{_scrubber} = $code;
@@ -142,7 +142,7 @@ sub test_transaction {
     if (! defined $testMode) { $testMode = $self->{'test_transaction'} || 0; }
 
     if (lc($testMode) eq 'sandbox') {
-    $self->{'test_transaction'} = 'sandbox';
+        $self->{'test_transaction'} = 'sandbox';
         $self->verify_SSL(0);
 
         $self->server('www.testvantivcnp.com');
@@ -154,7 +154,7 @@ sub test_transaction {
         $self->chargeback_path('/services/communicator/chargebacks/webCommunicator');
     } elsif (lc($testMode) eq 'localhost') {
         # this allows the user to create a local web server to do generic testing with
-    $self->{'test_transaction'} = 'localhost';
+        $self->{'test_transaction'} = 'localhost';
         $self->verify_SSL(0);
 
         $self->server('localhost');
@@ -165,7 +165,7 @@ sub test_transaction {
         $self->chargeback_port('443');
         $self->chargeback_path('/services/communicator/chargebacks/webCommunicator');
     } elsif (lc($testMode) eq 'prelive') {
-    $self->{'test_transaction'} = $testMode;
+        $self->{'test_transaction'} = $testMode;
         $self->verify_SSL(0);
 
         $self->server('payments.vantivprelive.com');
@@ -176,7 +176,7 @@ sub test_transaction {
         $self->chargeback_port('443');
         $self->chargeback_path('/services/communicator/chargebacks/webCommunicator');
     } elsif ($testMode) {
-    $self->{'test_transaction'} = $testMode;
+        $self->{'test_transaction'} = $testMode;
         $self->verify_SSL(0);
 
         $self->server('payments.vantivpostlive.com');
@@ -187,7 +187,7 @@ sub test_transaction {
         $self->chargeback_port('443');
         $self->chargeback_path('/services/communicator/chargebacks/webCommunicator');
     } else {
-    $self->{'test_transaction'} = 0;
+        $self->{'test_transaction'} = 0;
         $self->verify_SSL(1);
 
         $self->server('payments.vantivcnp.com');
@@ -433,13 +433,14 @@ sub map_request {
     tie my %billToAddress, 'Tie::IxHash', $self->_revmap_fields(
         content      => $content,
         name         => 'name',
-        email        => 'email',
         addressLine1 => 'address',
+        addressLine2 => 'address2',
+        addressLine3 => 'address3',
         city         => 'city',
         state        => 'state',
         zip          => 'zip',
-        country      => 'country'
-        , #TODO: will require validation to the spec, this field wont' work as is
+        country      => 'country',
+        email        => 'email',
         phone => 'phone',
     );
 
@@ -1230,7 +1231,7 @@ sub create_batch {
 
     my $post_data;
 
-    my $writer = XML::Writer(
+    my $writer = XML::Writer->new(
         OUTPUT      => \$post_data,
         DATA_MODE   => 1,
         DATA_INDENT => 2,
@@ -1301,7 +1302,7 @@ sub create_batch {
           "$filename.asc" ) #once complete, you rename it, for pickup
           or $self->die("Cannot RENAME file", $sftp->error);
         $self->is_success(1);
-        $self->server_response( $sftp->message );
+        $self->server_response( $sftp->error );
     }
     elsif ( $opts{'method'} && $opts{'method'} eq 'https' ) {    #https post
         $self->port('15000');
@@ -1925,7 +1926,7 @@ Business::OnlinePayment::Litle - Business::OnlinePayment::Litle - Vantiv (was Li
 
 =head1 VERSION
 
-version 0.958
+version 0.959
 
 =head1 SYNOPSIS
 
